<?php 

 /**
 * Get font face styles.
 * 
 * @return void
 */
function hotell_get_font_face_styles() {

	return "
		@font-face{
			font-family: 'Amaranth';
			font-weight: 400;
			font-style: normal;
			font-stretch: normal;
			font-display: swap;
			src: url('" . get_theme_file_uri( 'assets/fonts/Amaranth-Regular.ttf' ) . "');
		}
		@font-face{
            font-family: 'Sarabun';
            font-weight: 400;
            font-style: regular;
            font-stretch: normal;
            font-display: swap;
            src: url('" . get_theme_file_uri( 'assets/fonts/Sarabun-Regular.ttf' ) . "');
        }
        @font-face{
            font-family: 'Sarabun';
            font-weight: 500;
            font-style: normal;
            font-stretch: normal;
            font-display: swap;
            src: url('" . get_theme_file_uri( 'assets/fonts/Sarabun-Medium.ttf' ) . "');
        }
		";
}

/**
 * Pluggable functions for hotell header
 *
 * @return void
 */

function hotell_header(){ 
    $btn_lbl      = get_theme_mod( 'header_btn_lbl' );
    $btn_link     = get_theme_mod( 'header_btn_link' );
    $open_new_tab = get_theme_mod( 'header_new_tab', false );
    $new_tab      = ( $open_new_tab ) ? 'target=_blank' : '';
    $social_links = get_theme_mod( 'social_links' );
    $ed_social    = get_theme_mod( 'ed_social_links', false );
    $location     = get_theme_mod( 'header_location' );
    $header_tel   = get_theme_mod( 'header_tel' ); 
    $email        = get_theme_mod( 'email' ); 
    ?>
    <header id="masthead" class="site-header header-two" itemscope itemtype="http://schema.org/WPHeader">
        <?php if( $location || $email || $header_tel || ( $ed_social && $social_links ) ){ ?> 
            <div class="header-top clearfix">
                <div class="container">
                    <div class="header-top-left"> 
                        <?php 
                            $location = get_theme_mod( 'header_location' );
							if( $location || $header_tel ){ ?>
								<div class="info">
									<?php
										if( $location ) echo '<span class="location-link">' . homestay_icons_svg_list( 'location' ) . esc_html( $location ) . '</span>';
										if( $header_tel ) echo '<a href="' . esc_html( $header_tel ) . '" class="header-tel">' . homestay_icons_svg_list( 'phone' ) . esc_html( $header_tel ) . '</span>';
									?>
								</div>
							<?php } 
						?>
                    </div>
                    <div class="header-top-right">
                        <?php if( $email ) echo '<a href="' . esc_url( 'mailto:' . sanitize_email( $email ) ) . '" class="email-link">' .homestay_icons_svg_list( 'email' ) . esc_html( $email ) . '</a>';
                        hotell_social_links( true ); ?>
                    </div>
                </div>
            </div>
        <?php } ?>    
            <div class="desktop-header">
                <div class="header-bottom">
                    <div class="container">
                        <div class="header-wrapper">
							<?php hotell_site_branding(); ?>
							<div class="header-left">
								<?php hotell_primary_nagivation(); ?>
							</div>
							<div class="header-right">
								<?php if( $btn_lbl && $btn_link ) echo '<div class="book-btn"><a href="' . esc_url( $btn_link ) . '" class="btn btn-sm btn-outline"' . esc_attr( $new_tab ) . '>' . esc_html( $btn_lbl ) . '</a></div>'; ?>
							</div>
                        </div>
                    </div>
                </div>
            </div>
            <?php
            /**
             * Mobile Navigation
            */
            hotell_mobile_navigation();
        ?>
    </header>
<?php 
}

/**
 * Pluggable Function For Hotell Banner
 *
 * @return void
 */

function hotell_get_banner(){
    $ed_banner      = get_theme_mod( 'ed_banner_section', 'static_banner' );
    $read_more      = get_theme_mod( 'slider_readmore', esc_html__( 'Explore Us', 'homestay' ) );
    $read_more_link = get_theme_mod( 'banner_readmore_link', '#' );
    $btn_lbl        = get_theme_mod( 'slider_btn_lbl', esc_html__( 'Learn More', 'homestay' ) );
    $btn_link       = get_theme_mod( 'slider_btn_link', '#' );
    $slider_target  = get_theme_mod( 'slider_btn_new_tab', false ) ? 'target=_blank' : '';
    $banner_title   = get_theme_mod( 'banner_title', esc_html__( 'Discover the warmth of a home away from home.', 'homestay' ) );
    $rating_count   = get_theme_mod( 'rating_count' );
    $rating_text    = get_theme_mod( 'rating_text' );
    $rating_image   = attachment_url_to_postid( get_theme_mod( 'rating_image' )  );

    if( ( $ed_banner == 'static_banner' ) || has_custom_header() ){ ?>
        <div id="banner_section" class="banner left-align <?php if( has_header_video() ) echo esc_attr( ' banner-video ' ); ?>">
            <div class="container">
                <div class="banner__wrapper">
                    <div class="banner__left">
                        <?php
                            if( $ed_banner == 'static_banner' || ( $banner_title || ( $btn_lbl && $btn_link ) ) ){ ?>
                                <div class="banner__wrap">
                                    <div class="container">
                                        <div class="banner__text">
                                            <?php
                                                if ( $banner_title ) echo '<h2 class="banner__title">' . esc_html( $banner_title ) . '</h2>';
                                                if( ( $btn_lbl && $btn_link ) || ( $read_more && $read_more_link ) ) { ?>
                                                    <div class="btn-wrap">
                                                        <?php
                                                            if( $btn_lbl && $btn_link ) echo '<a href="' . esc_url( $btn_link ) . '" class="btn btn-lg btn-primary"' . esc_attr( $slider_target ) . '>' . esc_html( $btn_lbl ) . '</a>';
                                                            if( $read_more && $read_more_link ) echo '<a href="' . esc_url( $read_more_link ) . '" class="btn btn-lg btn-outline btn-white"' . esc_attr( $slider_target ) . '>' . esc_html( $read_more ) . '</a>';
                                                        ?>
                                                    </div>
                                                <?php }
                                                if ( $rating_count || $rating_text || $rating_image ) { ?>
                                                    <div class="banner__ratings-wrap">
                                                        <span><?php echo esc_html( $rating_count ); ?></span>
                                                        <span><?php echo esc_html( $rating_text ); ?></span>
                                                        <?php echo wp_get_attachment_image( $rating_image, 'full'); ?>
                                                    </div>
                                                <?php
                                                }
                                            ?>
                                        </div>
                                    </div>
                                </div>
                            <?php } 
                        ?>
                    </div>
                    <div class="banner__right">
                        <?php the_custom_header_markup(); ?>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }
}

/**
 * Pluggable Function For Hotell Blog Section
 *
 * @return void
 */
function hotell_card_content(){
    echo '<div class="card__content">';
        the_title( '<h5><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h5>' );
        if( has_excerpt() ){
            the_excerpt();
        }else{
            echo wpautop( wp_trim_words( get_the_content(),10,'..' ) );
        }
        hotell_posts_meta();
    echo '</div>';
}

/**
 * Pluggable Function For Hotell Blog Meta
 *
 * @return void
 */
function hotell_icon_meta(){
    $ed_author_img = get_theme_mod( 'ed_author_img', false ); ?>
    <ul class="meta">
        <li>
            <?php
				if( $ed_author_img ){
					echo '<span class="author-details">';
						echo get_avatar( get_the_author_meta( 'ID' ), 32 );
					echo '</span>';
				} else {
					echo hotell_misc_svg( 'admin' );
				}
			?>
			<div class="post-meta">
				<span class="gl-author">
					<?php hotell_posted_by(); ?>
				</span>
				<?php the_date( 'j M, Y', '<span class="date">', '</span>' ); ?>
			</div>
        </li>
        <li>
            <?php echo hotell_misc_svg( 'comment' ); ?>
            <span class="comment-count"><?php echo esc_html( get_comments_number_text( '0 comments', '1 comment', '% comments', get_the_ID() ) ); ?></span>
        </li>
    </ul>
<?php 
}

/**
 * Filter for banner Image
 * 
 * @return void
 */
add_filter( 'hotell_custom_header_args', function(){
    return array(
        'default-image' => get_stylesheet_directory_uri() . '/assets/images/banner.jpg',
        'video'         => true,
        'width'         => 776,
        'height'        => 650,
        'header-text'   => false
    );
});


/**
 * Homestay SVG Function 
 * 
 * @return void
 */

function homestay_icons_svg_list( $social ){
    if( !$social ){
        return;
    }
    switch ( $social ) {
        case 'phone':
            return '<svg width="16" height="16" viewBox="0 0 16 16" fill="none" xmlns="http://www.w3.org/2000/svg">
            <path d="M14.6667 10.9167C13.6667 10.9167 12.5833 10.75 11.6667 10.4167H11.4167C11.1667 10.4167 11 10.5 10.8333 10.6667L9 12.5C6.66667 11.25 4.66667 9.33333 3.5 7L5.33333 5.16667C5.58333 4.91667 5.66667 4.58333 5.5 4.33333C5.25 3.41667 5.08333 2.33333 5.08333 1.33333C5.08333 0.916667 4.66667 0.5 4.25 0.5H1.33333C0.916667 0.5 0.5 0.916667 0.5 1.33333C0.5 9.16667 6.83333 15.5 14.6667 15.5C15.0833 15.5 15.5 15.0833 15.5 14.6667V11.75C15.5 11.3333 15.0833 10.9167 14.6667 10.9167ZM2.16667 2.16667H3.41667C3.5 2.91667 3.66667 3.66667 3.83333 4.33333L2.83333 5.33333C2.5 4.33333 2.25 3.25 2.16667 2.16667ZM13.8333 13.8333C12.75 13.75 11.6667 13.5 10.6667 13.1667L11.6667 12.1667C12.3333 12.3333 13.0833 12.5 13.8333 12.5V13.8333Z" fill="white"/>
            </svg>
            ';
        break;

        case 'email':
            return '<svg width="18" height="14" viewBox="0 0 18 14" fill="none" xmlns="http://www.w3.org/2000/svg">
            <path d="M17.3333 2.00001C17.3333 1.08334 16.5833 0.333344 15.6667 0.333344H2.33334C1.41667 0.333344 0.666672 1.08334 0.666672 2.00001V12C0.666672 12.9167 1.41667 13.6667 2.33334 13.6667H15.6667C16.5833 13.6667 17.3333 12.9167 17.3333 12V2.00001ZM15.6667 2.00001L9.00001 6.15834L2.33334 2.00001H15.6667ZM15.6667 12H2.33334V3.66668L9.00001 7.83334L15.6667 3.66668V12Z" fill="white"/>
            </svg>';
        break;

        case 'location':
            return '<svg width="14" height="18" viewBox="0 0 14 18" fill="none" xmlns="http://www.w3.org/2000/svg">
            <path d="M7.12737 9.15923C7.59446 9.15923 7.99446 8.99277 8.32737 8.65986C8.65971 8.32752 8.82588 7.9278 8.82588 7.46071C8.82588 6.99362 8.65971 6.59362 8.32737 6.26071C7.99446 5.92837 7.59446 5.7622 7.12737 5.7622C6.66028 5.7622 6.26056 5.92837 5.92822 6.26071C5.59531 6.59362 5.42885 6.99362 5.42885 7.46071C5.42885 7.9278 5.59531 8.32752 5.92822 8.65986C6.26056 8.99277 6.66028 9.15923 7.12737 9.15923ZM7.12737 15.4013C8.85419 13.816 10.1352 12.3756 10.9703 11.0802C11.8054 9.78541 12.2229 8.63552 12.2229 7.63056C12.2229 6.08775 11.7309 4.82434 10.7469 3.84033C9.76346 2.85689 8.55695 2.36517 7.12737 2.36517C5.69779 2.36517 4.49099 2.85689 3.50699 3.84033C2.52355 4.82434 2.03183 6.08775 2.03183 7.63056C2.03183 8.63552 2.44938 9.78541 3.28448 11.0802C4.11958 12.3756 5.40055 13.816 7.12737 15.4013ZM7.12737 17.3333C7.01413 17.3333 6.9009 17.3121 6.78767 17.2696C6.67443 17.2272 6.57535 17.1706 6.49043 17.0998C4.4239 15.2739 2.88108 13.579 1.86198 12.0153C0.842867 10.4509 0.333313 8.98938 0.333313 7.63056C0.333313 5.50742 1.0164 3.81598 2.38257 2.55625C3.74818 1.29652 5.32977 0.666656 7.12737 0.666656C8.92496 0.666656 10.5066 1.29652 11.8722 2.55625C13.2383 3.81598 13.9214 5.50742 13.9214 7.63056C13.9214 8.98938 13.4119 10.4509 12.3928 12.0153C11.3737 13.579 9.83084 15.2739 7.76431 17.0998C7.67939 17.1706 7.58031 17.2272 7.46707 17.2696C7.35384 17.3121 7.2406 17.3333 7.12737 17.3333Z" fill="white"/>
            </svg>';
        break;

        default:
            # code...
            break;
    }

}